Struct MatchedPath
pub struct MatchedPath(/* private fields */);Expand description
Access the path in the router that matches the request.
use axum::{
Router,
extract::MatchedPath,
routing::get,
};
let app = Router::new().route(
"/users/{id}",
get(|path: MatchedPath| async move {
let path = path.as_str();
// `path` will be "/users/{id}"
})
);Accessing MatchedPath via extensions
MatchedPath can also be accessed from middleware via request extensions.
This is useful for example with Trace to
create a span that contains the matched path:
use axum::{
Router,
extract::{Request, MatchedPath},
routing::get,
};
use tower_http::trace::TraceLayer;
let app = Router::new()
.route("/users/{id}", get(|| async { /* ... */ }))
.layer(
TraceLayer::new_for_http().make_span_with(|req: &Request<_>| {
let path = if let Some(path) = req.extensions().get::<MatchedPath>() {
path.as_str()
} else {
req.uri().path()
};
tracing::info_span!("http-request", %path)
}),
);Implementations
impl MatchedPath
impl MatchedPath