Struct OriginalUri
pub struct OriginalUri(pub Uri);Expand description
Extractor that gets the original request URI regardless of nesting.
This is necessary since Uri, when used as an extractor, will
have the prefix stripped if used in a nested service.
Example
use axum::{
routing::get,
Router,
extract::OriginalUri,
http::Uri
};
let api_routes = Router::new()
.route(
"/users",
get(|uri: Uri, OriginalUri(original_uri): OriginalUri| async {
// `uri` is `/users`
// `original_uri` is `/api/users`
}),
);
let app = Router::new().nest("/api", api_routes);Extracting via request extensions
OriginalUri can also be accessed from middleware via request extensions.
This is useful for example with Trace to
create a span that contains the full path, if your service might be nested:
use axum::{
Router,
extract::OriginalUri,
http::Request,
routing::get,
};
use tower_http::trace::TraceLayer;
let api_routes = Router::new()
.route("/users/{id}", get(|| async { /* ... */ }))
.layer(
TraceLayer::new_for_http().make_span_with(|req: &Request<_>| {
let path = if let Some(path) = req.extensions().get::<OriginalUri>() {
// This will include `/api`
path.0.path().to_owned()
} else {
// The `OriginalUri` extension will always be present if using
// `Router` unless another extractor or middleware has removed it
req.uri().path().to_owned()
};
tracing::info_span!("http-request", %path)
}),
);
let app = Router::new().nest("/api", api_routes);Tuple Fields
0: UriMethods from Deref<Target = Uri>
pub fn path_and_query(&self) -> Option<&PathAndQuery>
pub fn path_and_query(&self) -> Option<&PathAndQuery>
Returns the path & query components of the Uri
pub fn path(&self) -> &str
pub fn path(&self) -> &str
Get the path of this Uri.
Both relative and absolute URIs contain a path component, though it might be the empty string. The path component is case sensitive.
abc://username:password@example.com:123/path/data?key=value&key2=value2#fragid1
|--------|
|
pathIf the URI is * then the path component is equal to *.
Examples
A relative URI
let uri: Uri = "/hello/world".parse().unwrap();
assert_eq!(uri.path(), "/hello/world");An absolute URI
let uri: Uri = "http://example.org/hello/world".parse().unwrap();
assert_eq!(uri.path(), "/hello/world");pub fn scheme(&self) -> Option<&Scheme>
pub fn scheme(&self) -> Option<&Scheme>
Get the scheme of this Uri.
The URI scheme refers to a specification for assigning identifiers within that scheme. Only absolute URIs contain a scheme component, but not all absolute URIs will contain a scheme component. Although scheme names are case-insensitive, the canonical form is lowercase.
abc://username:password@example.com:123/path/data?key=value&key2=value2#fragid1
|-|
|
schemeExamples
Absolute URI
use http::uri::{Scheme, Uri};
let uri: Uri = "http://example.org/hello/world".parse().unwrap();
assert_eq!(uri.scheme(), Some(&Scheme::HTTP));Relative URI
let uri: Uri = "/hello/world".parse().unwrap();
assert!(uri.scheme().is_none());pub fn scheme_str(&self) -> Option<&str>
pub fn scheme_str(&self) -> Option<&str>
Get the scheme of this Uri as a &str.
Example
let uri: Uri = "http://example.org/hello/world".parse().unwrap();
assert_eq!(uri.scheme_str(), Some("http"));Get the authority of this Uri.
The authority is a hierarchical element for naming authority such that the remainder of the URI is delegated to that authority. For HTTP, the authority consists of the host and port. The host portion of the authority is case-insensitive.
The authority also includes a username:password component, however
the use of this is deprecated and should be avoided.
abc://username:password@example.com:123/path/data?key=value&key2=value2#fragid1
|-------------------------------|
|
authorityExamples
Absolute URI
let uri: Uri = "http://example.org:80/hello/world".parse().unwrap();
assert_eq!(uri.authority().map(|a| a.as_str()), Some("example.org:80"));Relative URI
let uri: Uri = "/hello/world".parse().unwrap();
assert!(uri.authority().is_none());pub fn host(&self) -> Option<&str>
pub fn host(&self) -> Option<&str>
Get the host of this Uri.
The host subcomponent of authority is identified by an IP literal encapsulated within square brackets, an IPv4 address in dotted- decimal form, or a registered name. The host subcomponent is case-insensitive.
abc://username:password@example.com:123/path/data?key=value&key2=value2#fragid1
|---------|
|
hostExamples
Absolute URI
let uri: Uri = "http://example.org:80/hello/world".parse().unwrap();
assert_eq!(uri.host(), Some("example.org"));Relative URI
let uri: Uri = "/hello/world".parse().unwrap();
assert!(uri.host().is_none());pub fn port(&self) -> Option<Port<&str>>
pub fn port(&self) -> Option<Port<&str>>
Get the port part of this Uri.
The port subcomponent of authority is designated by an optional port
number following the host and delimited from it by a single colon (“:”)
character. It can be turned into a decimal port number with the as_u16
method or as a str with the as_str method.
abc://username:password@example.com:123/path/data?key=value&key2=value2#fragid1
|-|
|
portExamples
Absolute URI with port
let uri: Uri = "http://example.org:80/hello/world".parse().unwrap();
let port = uri.port().unwrap();
assert_eq!(port.as_u16(), 80);Absolute URI without port
let uri: Uri = "http://example.org/hello/world".parse().unwrap();
assert!(uri.port().is_none());Relative URI
let uri: Uri = "/hello/world".parse().unwrap();
assert!(uri.port().is_none());pub fn port_u16(&self) -> Option<u16>
pub fn port_u16(&self) -> Option<u16>
Get the port of this Uri as a u16.
Example
let uri: Uri = "http://example.org:80/hello/world".parse().unwrap();
assert_eq!(uri.port_u16(), Some(80));pub fn query(&self) -> Option<&str>
pub fn query(&self) -> Option<&str>
Get the query string of this Uri, starting after the ?.
The query component contains non-hierarchical data that, along with data in the path component, serves to identify a resource within the scope of the URI’s scheme and naming authority (if any). The query component is indicated by the first question mark (“?”) character and terminated by a number sign (“#”) character or by the end of the URI.
abc://username:password@example.com:123/path/data?key=value&key2=value2#fragid1
|-------------------|
|
queryExamples
Absolute URI
let uri: Uri = "http://example.org/hello/world?key=value".parse().unwrap();
assert_eq!(uri.query(), Some("key=value"));Relative URI with a query string component
let uri: Uri = "/hello/world?key=value&foo=bar".parse().unwrap();
assert_eq!(uri.query(), Some("key=value&foo=bar"));Relative URI without a query string component
let uri: Uri = "/hello/world".parse().unwrap();
assert!(uri.query().is_none());Trait Implementations
impl Clone for OriginalUri
impl Clone for OriginalUri
fn clone(&self) -> OriginalUri
fn clone(&self) -> OriginalUri
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Debug for OriginalUri
impl Debug for OriginalUri
impl Deref for OriginalUri
impl Deref for OriginalUri
impl DerefMut for OriginalUri
impl DerefMut for OriginalUri
fn deref_mut(&mut self) -> &mut <OriginalUri as Deref>::Target
fn deref_mut(&mut self) -> &mut <OriginalUri as Deref>::Target
impl<S> FromRequestParts<S> for OriginalUri
impl<S> FromRequestParts<S> for OriginalUri
type Rejection = Infallible
type Rejection = Infallible
async fn from_request_parts(
parts: &mut Parts,
state: &S,
) -> Result<OriginalUri, <OriginalUri as FromRequestParts<S>>::Rejection>
async fn from_request_parts( parts: &mut Parts, state: &S, ) -> Result<OriginalUri, <OriginalUri as FromRequestParts<S>>::Rejection>