FromRequestParts

Trait FromRequestParts 

pub trait FromRequestParts<S>: Sized {
    type Rejection: IntoResponse;

    // Required method
    fn from_request_parts(
        parts: &mut Parts,
        state: &S,
    ) -> impl Future<Output = Result<Self, Self::Rejection>> + Send;
}
Types that can be created from request parts.

Extractors that implement FromRequestParts cannot consume the request body and can thus be run in any order for handlers.

If your extractor needs to consume the request body then you should implement FromRequest and not FromRequestParts.

See axum::extract for more general docs about extractors.

Required Associated Types

type Rejection: IntoResponse

If the extractor fails it’ll use this “rejection” type. A rejection is a kind of error that can be converted into a response.

Required Methods

fn from_request_parts( parts: &mut Parts, state: &S, ) -> impl Future<Output = Result<Self, Self::Rejection>> + Send

Perform the extraction.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types



impl<S> FromRequestParts<S> for ()
where S: Send + Sync,



impl<S, T1> FromRequestParts<S> for (T1,)
where T1: FromRequestParts<S> + Send, S: Send + Sync,



type Rejection = Response<Body>



async fn from_request_parts( parts: &mut Parts, state: &S, ) -> Result<(T1,), <(T1,) as FromRequestParts<S>>::Rejection>



impl<S, T1, T2> FromRequestParts<S> for (T1, T2)
where T1: FromRequestParts<S> + Send, T2: FromRequestParts<S> + Send, S: Send + Sync,



impl<S, T1, T2, T3> FromRequestParts<S> for (T1, T2, T3)
where T1: FromRequestParts<S> + Send, T2: FromRequestParts<S> + Send, T3: FromRequestParts<S> + Send, S: Send + Sync,



impl<S, T1, T2, T3, T4> FromRequestParts<S> for (T1, T2, T3, T4)
where T1: FromRequestParts<S> + Send, T2: FromRequestParts<S> + Send, T3: FromRequestParts<S> + Send, T4: FromRequestParts<S> + Send, S: Send + Sync,



impl<S, T1, T2, T3, T4, T5> FromRequestParts<S> for (T1, T2, T3, T4, T5)
where T1: FromRequestParts<S> + Send, T2: FromRequestParts<S> + Send, T3: FromRequestParts<S> + Send, T4: FromRequestParts<S> + Send, T5: FromRequestParts<S> + Send, S: Send + Sync,



impl<S, T1, T2, T3, T4, T5, T6> FromRequestParts<S> for (T1, T2, T3, T4, T5, T6)



impl<S, T1, T2, T3, T4, T5, T6, T7> FromRequestParts<S> for (T1, T2, T3, T4, T5, T6, T7)



impl<S, T1, T2, T3, T4, T5, T6, T7, T8> FromRequestParts<S> for (T1, T2, T3, T4, T5, T6, T7, T8)



impl<S, T1, T2, T3, T4, T5, T6, T7, T8, T9> FromRequestParts<S> for (T1, T2, T3, T4, T5, T6, T7, T8, T9)



impl<S, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> FromRequestParts<S> for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)



impl<S, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> FromRequestParts<S> for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)



impl<S, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12> FromRequestParts<S> for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12)



impl<S, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13> FromRequestParts<S> for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13)



impl<S, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14> FromRequestParts<S> for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14)



impl<S, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> FromRequestParts<S> for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15)



impl<S, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16> FromRequestParts<S> for (T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16)



impl<S, T> FromRequestParts<S> for Option<T>



type Rejection = <T as OptionalFromRequestParts<S>>::Rejection



fn from_request_parts( parts: &mut Parts, state: &S, ) -> impl Future<Output = Result<Option<T>, <Option<T> as FromRequestParts<S>>::Rejection>>



impl<S, T> FromRequestParts<S> for Result<T, <T as FromRequestParts<S>>::Rejection>
where T: FromRequestParts<S>, S: Send + Sync,



type Rejection = Infallible



async fn from_request_parts( parts: &mut Parts, state: &S, ) -> Result<Result<T, <T as FromRequestParts<S>>::Rejection>, <Result<T, <T as FromRequestParts<S>>::Rejection> as FromRequestParts<S>>::Rejection>

Implementors



impl<OuterState, InnerState> FromRequestParts<OuterState> for State<InnerState>
where InnerState: FromRef<OuterState>, OuterState: Send + Sync,



impl<S> FromRequestParts<S> for Parts
where S: Send + Sync,



impl<S> FromRequestParts<S> for Extensions
where S: Send + Sync,



impl<S> FromRequestParts<S> for HeaderMap
where S: Send + Sync,

Clone the headers from the request.

Prefer using TypedHeader to extract only the headers you need.



impl<S> FromRequestParts<S> for Method
where S: Send + Sync,



impl<S> FromRequestParts<S> for Uri
where S: Send + Sync,



impl<S> FromRequestParts<S> for Version
where S: Send + Sync,



impl<S> FromRequestParts<S> for MatchedPath
where S: Send + Sync,



impl<S> FromRequestParts<S> for NestedPath
where S: Send + Sync,



impl<S> FromRequestParts<S> for OriginalUri
where S: Send + Sync,



impl<S> FromRequestParts<S> for RawPathParams
where S: Send + Sync,



impl<S> FromRequestParts<S> for RawQuery
where S: Send + Sync,



impl<S, T> FromRequestParts<S> for ConnectInfo<T>
where S: Send + Sync, T: Clone + Send + Sync + 'static,



impl<T, S> FromRequestParts<S> for Extension<T>
where T: Clone + Send + Sync + 'static, S: Send + Sync,



impl<T, S> FromRequestParts<S> for Path<T>
where T: DeserializeOwned + Send, S: Send + Sync,



impl<T, S> FromRequestParts<S> for Query<T>
where T: DeserializeOwned, S: Send + Sync,